@@ -1,8 +1,15 @@
 as.signed <-
 function (x, lbs) 
 {
-    if (is.array(x) == FALSE) 
+    if (isTRUE(attr(x, "class")[1] == "Rel.Q") == TRUE) {
+        x <- x$Q
+    }
+    else if (is.array(x) == FALSE) {
         stop("Data must be an array")
+    }
+    else {
+        NA
+    }
     if (is.na(dim(x)[3]) == FALSE) {
         sm <- x[, , 1]
         warning("Take the 1st dim. in 'x' only.")
@@ -15,7 +22,8 @@ function (x, lbs)
         rownames(sm) <- colnames(sm) <- lbs
     }
     else {
-        rownames(sm) <- colnames(sm) <- seq_len(dim(sm)[1])
+        ifelse(isTRUE(dimnames(x)[[1]]) == TRUE, rownames(sm) <- colnames(sm) <- seq_len(dim(sm)[1]), 
+            rownames(sm) <- colnames(sm) <- dimnames(x)[[1]])
     }
     val <- levels(factor(sm))
     lst <- list(val = noquote(levels(stats::reorder(val, length(val):1))), 
